@@ -121,6 +121,11 @@ class SmdaReport(object):
             self.capstone.detail = True
         return self.capstone
 
+    def getSection(self, offset):
+        for section in self.code_sections:
+            if section[1] <= offset < section[2]:
+                return section
+
     def isAddrWithinMemoryImage(self, offset):
         return self.base_addr <= offset < self.base_addr + self.binary_size
 
